@@ -1,4 +1,4 @@
-"""Tested with Python 2.7.8(CYGWIN), 2.7.9(OS X/Linux), 3.4.3(OS X/Linux)"""
+"""Tested with Python 2.7.6 (OS X), 2.7.8(CYGWIN), 2.7.9(OS X/Linux), 3.4.3(OS X/Linux)"""
 import os
 import sys
 import time
@@ -6,9 +6,10 @@ import datetime
 import getpass
 import shlex
 import subprocess
+import logging
 
 """Backup your Digitalocean Droplets"""
-__version__ = '1.0.2'
+__version__ = '1.0.4'
 __author__ = 'Rob Johnson ( https://corndogcomputers.com )'
 __author_email__ = 'info@corndogcomputers.com'
 __license__ = 'The MIT License (MIT)'
@@ -39,19 +40,29 @@ class Backup(object):
         self.rsync_excludes = []
         self.freshlog = False
         self.use_ip = False
+        self.debug = False
         self.user = getpass.getuser()
         self.home = os.path.expanduser('~')
         self.backup_dir = '%s/Droplets' % self.home
         self.snapshot_hour = 25
         self.keep_snapshots = 0
+        self.debug = False
 
         """Currently no support for Windows without CYGWIN"""
         if os.name != 'posix':
-            sys.exit('Currently only supports POSIX OS.')
+            sys.exit('Currently only supports POSIX platform.')
 
         """Set attributes from args."""
         self.__dict__.update(kwargs)
 
+        """Setup logger."""
+        logging.captureWarnings(True)
+        if self.debug == True:
+            logging.basicConfig(level=logging.DEBUG)
+        else:
+            logging.basicConfig(level=logging.ERROR)
+        self.logger = logging.getLogger(__name__)
+
         """Let's check to make sure a droplet was passed in."""
         if hasattr(self, 'droplet') == True:
             """Set the prefered route (ip or droplet name)."""
@@ -79,7 +90,7 @@ class Backup(object):
             self.logfile = '%s/%s' % (self.backup_dir, '_backup_log.md')
             self.success = self.__rsync()
         else:
-            sys.exit('No droplet specified for backup...\n')
+            sys.exit('No droplet specified for backup.\n')
 
     """Add entry to self.logfile."""
 
@@ -109,7 +120,9 @@ class Backup(object):
         ssh_path = '%s/.ssh/%s' % (self.home, self.ssh_key)
         paths = [self.ssh_key, this_path, home_path, ssh_path]
         for path in paths:
+            self.logger.debug('LOOKING FOR ssh_key in ' + path)
             if os.path.isfile(path):
+                self.logger.debug('FOUND ssh_key ' + path)
                 return path
         sys.exit('could not find ssh_key: %s' % self.ssh_key)
 
@@ -164,6 +177,7 @@ class Backup(object):
     """Run shell commands on droplet."""
 
     def __run_process(self, process):
+        self.logger.debug(process)
         try:
             output = subprocess.Popen(
                 shlex.split(process),
@@ -175,7 +189,7 @@ class Backup(object):
         except subprocess.CalledProcessError as grepexc:
             status = grepexc.returncode
             output = grepexc.output
-            print(status, output)
+            self.logger.ERROR(status, output)
         return output
 
     """This will delete old snapshots created by this backup."""
